@@ -28,9 +28,6 @@
 
 #include <glib/gi18n.h>
 #include <gio/gio.h>
-#include <dbus/dbus.h>
-#include <dbus/dbus-glib-lowlevel.h>
-#include <dbus/dbus-glib.h>
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -50,8 +47,6 @@
 #include <locale.h>
 
 #include <NetworkManager.h>
-#include <NetworkManagerVPN.h>
-#include <nm-setting-vpn.h>
 
 #include "nm-ssh-service.h"
 #include "nm-utils.h"
@@ -63,7 +58,7 @@
 static gboolean debug = FALSE;
 static GMainLoop *loop = NULL;
 
-G_DEFINE_TYPE (NMSshPlugin, nm_ssh_plugin, NM_TYPE_VPN_PLUGIN)
+G_DEFINE_TYPE (NMSshPlugin, nm_ssh_plugin, NM_TYPE_VPN_SERVICE_PLUGIN)
 
 #define NM_SSH_PLUGIN_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), NM_TYPE_SSH_PLUGIN, NMSshPluginPrivate))
 
@@ -239,7 +234,7 @@ validate_one_property (const char *key, const char *value, gpointer user_data)
 }
 
 static gboolean
-nm_ssh_properties_validate (NMSettingVPN *s_vpn, GError **error)
+nm_ssh_properties_validate (NMSettingVpn *s_vpn, GError **error)
 {
 	GError *validate_error = NULL;
 	ValidateInfo info = { &valid_properties[0], &validate_error, FALSE };
@@ -261,27 +256,12 @@ nm_ssh_properties_validate (NMSettingVPN *s_vpn, GError **error)
 	return TRUE;
 }
 
-static GValue *
-uint_to_gvalue (guint32 num)
-{
-	GValue *val;
-
-	if (num == 0)
-		return NULL;
-
-	val = g_slice_new0 (GValue);
-	g_value_init (val, G_TYPE_UINT);
-	g_value_set_uint (val, num);
-
-	return val;
-}
-
-static GValue *
-addr6_to_gvalue (const char *str)
+static GVariant *
+addr6_to_gvariant (const char *str)
 {
 	struct in6_addr temp_addr;
-	GValue *val;
-	GByteArray *ba;
+	GVariantBuilder builder;
+	int i;
 
 	/* Empty */
 	if (!str || strlen (str) < 1)
@@ -290,30 +270,15 @@ addr6_to_gvalue (const char *str)
 	if (inet_pton (AF_INET6, str, &temp_addr) <= 0)
 		return NULL;
 
-	val = g_slice_new0 (GValue);
-	g_value_init (val, DBUS_TYPE_G_UCHAR_ARRAY);
-	ba = g_byte_array_new ();
-	g_byte_array_append (ba, (guint8 *) &temp_addr, sizeof (temp_addr));
-	g_value_take_boxed (val, ba);
-	return val;
+	g_variant_builder_init (&builder, G_VARIANT_TYPE ("ay"));
+	for (i = 0; i < sizeof (temp_addr); i++)
+		g_variant_builder_add (&builder, "y", ((guint8 *) &temp_addr)[i]);
+	return g_variant_builder_end (&builder);
 }
 
-static GValue *
-bool_to_gvalue (gboolean b)
+static GVariant *
+str_to_gvariant (const char *str, gboolean try_convert)
 {
-	GValue *val;
-
-	val = g_slice_new0 (GValue);
-	g_value_init (val, G_TYPE_BOOLEAN);
-	g_value_set_boolean (val, b);
-	return val;
-}
-
-static GValue *
-str_to_gvalue (const char *str, gboolean try_convert)
-{
-	GValue *val;
-
 	/* Empty */
 	if (!str || strlen (str) < 1)
 		return NULL;
@@ -327,18 +292,13 @@ str_to_gvalue (const char *str, gboolean try_convert)
 			return NULL;
 	}
 
-	val = g_slice_new0 (GValue);
-	g_value_init (val, G_TYPE_STRING);
-	g_value_set_string (val, str);
-
-	return val;
+	return g_variant_new_string (str);
 }
 
-static GValue *
-addr_to_gvalue (const char *str)
+static GVariant *
+addr4_to_gvariant (const char *str)
 {
 	struct in_addr	temp_addr;
-	GValue *val;
 
 	/* Empty */
 	if (!str || strlen (str) < 1)
@@ -347,11 +307,7 @@ addr_to_gvalue (const char *str)
 	if (inet_pton (AF_INET, str, &temp_addr) <= 0)
 		return NULL;
 
-	val = g_slice_new0 (GValue);
-	g_value_init (val, G_TYPE_UINT);
-	g_value_set_uint (val, temp_addr.s_addr);
-
-	return val;
+	return g_variant_new_uint32 (temp_addr.s_addr);
 }
 
 static char *
@@ -424,24 +380,14 @@ send_network_config (NMSshPlugin *plugin)
 {
 	NMSshPluginPrivate *priv = NM_SSH_PLUGIN_GET_PRIVATE (plugin);
 	NMSshPluginIOData  *io_data = priv->io_data;
-	DBusGConnection    *connection;
-	DBusGProxy         *proxy;
-	GHashTable         *config, *ip4config, *ip6config;
-	GValue             *val;
-	GError             *err = NULL;
+	GVariantBuilder     config, ip4config, ip6config;
+	GVariant           *val;
 	char               *device;
 	char               *resolved_hostname;
 
-	connection = dbus_g_bus_get (DBUS_BUS_SYSTEM, &err);
-	if (!connection) {
-		g_warning ("Could not get the system bus: %s", err->message);
-		nm_vpn_plugin_set_state ((NMVPNPlugin*)plugin, NM_VPN_SERVICE_STATE_STOPPED);
-		return FALSE;
-	}
-
-	config = g_hash_table_new (g_str_hash, g_str_equal);
-	ip4config = g_hash_table_new (g_str_hash, g_str_equal);
-	ip6config = g_hash_table_new (g_str_hash, g_str_equal);
+	g_variant_builder_init (&config, G_VARIANT_TYPE_VARDICT);
+	g_variant_builder_init (&ip4config, G_VARIANT_TYPE_VARDICT);
+	g_variant_builder_init (&ip6config, G_VARIANT_TYPE_VARDICT);
 
 	if (debug) {
 		g_message ("Local device: '%s%d'", io_data->dev_type, io_data->local_dev_number);
@@ -464,8 +410,8 @@ send_network_config (NMSshPlugin *plugin)
 		/* We might have to resolve that */
 		resolved_hostname = resolve_hostname (io_data->remote_gw);
 		if (resolved_hostname) {
-			val = addr_to_gvalue (resolved_hostname);
-			g_hash_table_insert (config, NM_VPN_PLUGIN_CONFIG_EXT_GATEWAY, val);
+			val = addr4_to_gvariant (resolved_hostname);
+			g_variant_builder_add (&config, "{sv}", NM_VPN_PLUGIN_CONFIG_EXT_GATEWAY, val);
 			g_free (resolved_hostname);
 		} else {
 			g_warning ("Could not resolve remote_gw.");
@@ -479,9 +425,9 @@ send_network_config (NMSshPlugin *plugin)
 	{
 		device =
 			(gpointer) g_strdup_printf ("%s%d", io_data->dev_type, io_data->local_dev_number);
-		val = str_to_gvalue (device, FALSE);
+		val = str_to_gvariant (device, FALSE);
 		g_free(device);
-		g_hash_table_insert (config, NM_VPN_PLUGIN_CONFIG_TUNDEV, val);
+		g_variant_builder_add (&config, "{sv}", NM_VPN_PLUGIN_CONFIG_TUNDEV, val);
 	}
 	else
 		g_warning ("local_dev_number unset.");
@@ -489,8 +435,8 @@ send_network_config (NMSshPlugin *plugin)
 	/* mtu */
 	if (io_data->mtu > 0)
 	{
-		val = str_to_gvalue (g_strdup_printf("%d", io_data->mtu), FALSE);
-		g_hash_table_insert (config, NM_VPN_PLUGIN_CONFIG_MTU, val);
+		val = str_to_gvariant (g_strdup_printf("%d", io_data->mtu), FALSE);
+		g_variant_builder_add (&config, "{sv}", NM_VPN_PLUGIN_CONFIG_MTU, val);
 	}
 	else
 		g_warning ("local_dev_number unset.");
@@ -500,18 +446,18 @@ send_network_config (NMSshPlugin *plugin)
 	/* ---------------------------------------------------- */
 
 	/* IPv4 specific (local_addr, remote_addr, netmask) */
-	g_hash_table_insert (config, NM_VPN_PLUGIN_CONFIG_HAS_IP4, bool_to_gvalue (TRUE));
+	g_variant_builder_add (&config, "{sv}", NM_VPN_PLUGIN_CONFIG_HAS_IP4, g_variant_new_boolean (TRUE));
 
 	/* replace default route? */
 	if (io_data->no_default_route) {
-		g_hash_table_insert (config, NM_VPN_PLUGIN_IP4_CONFIG_NEVER_DEFAULT, bool_to_gvalue (TRUE));
+		g_variant_builder_add (&config, "{sv}", NM_VPN_PLUGIN_IP4_CONFIG_NEVER_DEFAULT, g_variant_new_boolean (TRUE));
 	}
 
 	/* local_address */
 	if (io_data->local_addr)
 	{
-		val = addr_to_gvalue (io_data->local_addr);
-		g_hash_table_insert (ip4config, NM_VPN_PLUGIN_IP4_CONFIG_ADDRESS, val);
+		val = addr4_to_gvariant (io_data->local_addr);
+		g_variant_builder_add (&ip4config, "{sv}", NM_VPN_PLUGIN_IP4_CONFIG_ADDRESS, val);
 	}
 	else
 		g_warning ("local_addr unset.");
@@ -519,9 +465,9 @@ send_network_config (NMSshPlugin *plugin)
 	/* remote_addr */
 	if (io_data->remote_addr)
 	{
-		val = addr_to_gvalue (io_data->remote_addr);
-		g_hash_table_insert (ip4config, NM_VPN_PLUGIN_IP4_CONFIG_INT_GATEWAY, val);
-		g_hash_table_insert (ip4config, NM_VPN_PLUGIN_IP4_CONFIG_PTP, val);
+		val = addr4_to_gvariant (io_data->remote_addr);
+		g_variant_builder_add (&ip4config, "{sv}", NM_VPN_PLUGIN_IP4_CONFIG_INT_GATEWAY, val);
+		g_variant_builder_add (&ip4config, "{sv}", NM_VPN_PLUGIN_IP4_CONFIG_PTP, val);
 	}
 	else
 		g_warning ("remote_addr unset.");
@@ -529,10 +475,11 @@ send_network_config (NMSshPlugin *plugin)
 	/* netmask */
 	if (io_data->netmask && g_str_has_prefix (io_data->netmask, "255.")) {
 			guint32 addr;
-			val = addr_to_gvalue(io_data->netmask);
-			addr = g_value_get_uint (val);
-			g_value_set_uint (val, nm_utils_ip4_netmask_to_prefix (addr));
-			g_hash_table_insert (ip4config, NM_VPN_PLUGIN_IP4_CONFIG_PREFIX, val);
+			val = addr4_to_gvariant(io_data->netmask);
+			addr = g_variant_get_uint32 (val);
+			g_variant_unref (val);
+			val = g_variant_new_uint32 (nm_utils_ip4_netmask_to_prefix (addr));
+			g_variant_builder_add (&ip4config, "{sv}", NM_VPN_PLUGIN_IP4_CONFIG_PREFIX, val);
 	} else
 		g_warning ("netmask unset.");
 
@@ -542,18 +489,18 @@ send_network_config (NMSshPlugin *plugin)
 
 	/* IPv6 specific (local_addr_6, remote_addr_6, netmask_6) */
 	if (io_data->ipv6) {
-		g_hash_table_insert (config, NM_VPN_PLUGIN_CONFIG_HAS_IP6, bool_to_gvalue (TRUE));
+		g_variant_builder_add (&config, "{sv}", NM_VPN_PLUGIN_CONFIG_HAS_IP6, g_variant_new_boolean (TRUE));
 
 		/* replace default route? */
 		if (io_data->no_default_route) {
-			g_hash_table_insert (config, NM_VPN_PLUGIN_IP6_CONFIG_NEVER_DEFAULT, bool_to_gvalue (TRUE));
+			g_variant_builder_add (&config, "{sv}", NM_VPN_PLUGIN_IP6_CONFIG_NEVER_DEFAULT, g_variant_new_boolean (TRUE));
 		}
 
 		/* local_addr_6 */
 		if (io_data->local_addr_6)
 		{
-			val = addr6_to_gvalue (io_data->local_addr_6);
-			g_hash_table_insert (ip6config, NM_VPN_PLUGIN_IP6_CONFIG_ADDRESS, val);
+			val = addr6_to_gvariant (io_data->local_addr_6);
+			g_variant_builder_add (&ip6config, "{sv}", NM_VPN_PLUGIN_IP6_CONFIG_ADDRESS, val);
 		}
 		else
 			g_warning ("local_addr_6 unset.");
@@ -561,17 +508,17 @@ send_network_config (NMSshPlugin *plugin)
 		/* remote_addr_6 */
 		if (io_data->remote_addr_6)
 		{
-			val = addr6_to_gvalue (io_data->remote_addr_6);
-			g_hash_table_insert (ip6config, NM_VPN_PLUGIN_IP6_CONFIG_INT_GATEWAY, val);
-			g_hash_table_insert (ip6config, NM_VPN_PLUGIN_IP6_CONFIG_PTP, val);
+			val = addr6_to_gvariant (io_data->remote_addr_6);
+			g_variant_builder_add (&ip6config, "{sv}", NM_VPN_PLUGIN_IP6_CONFIG_INT_GATEWAY, val);
+			g_variant_builder_add (&ip6config, "{sv}", NM_VPN_PLUGIN_IP6_CONFIG_PTP, val);
 		}
 		else
 			g_warning ("remote_addr_6 unset.");
 	
 		/* netmask_6 */
 		if (io_data->netmask_6) {
-			val = uint_to_gvalue (strtol (io_data->netmask_6, NULL, 10));
-			g_hash_table_insert (ip6config, NM_VPN_PLUGIN_IP6_CONFIG_PREFIX, val);
+			val = g_variant_new_uint32 (strtol (io_data->netmask_6, NULL, 10));
+			g_variant_builder_add (&ip6config, "{sv}", NM_VPN_PLUGIN_IP6_CONFIG_PREFIX, val);
 		} else
 			g_warning ("netmask_6 unset.");
 	}
@@ -580,40 +527,19 @@ send_network_config (NMSshPlugin *plugin)
 
 	/* ---------------------------------------------------- */
 
-	proxy = dbus_g_proxy_new_for_name (
-		connection,
-		NM_DBUS_SERVICE_SSH,
-		NM_VPN_DBUS_PLUGIN_PATH,
-		NM_VPN_DBUS_PLUGIN_INTERFACE);
 
 	/* Send general config */
-	dbus_g_proxy_call_no_reply (
-		proxy, "SetConfig",
-		dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, G_TYPE_VALUE),
-		config,
-		G_TYPE_INVALID,
-		G_TYPE_INVALID);
+	nm_vpn_service_plugin_set_config ((NMVpnServicePlugin*) plugin,
+	                                  g_variant_builder_end (&config));
 
 	/* Send IPv6 config */
-	if (io_data->ipv6) {
-		dbus_g_proxy_call_no_reply (
-			proxy, "SetIp6Config",
-			dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, G_TYPE_VALUE),
-			ip6config,
-			G_TYPE_INVALID,
-			G_TYPE_INVALID);
-	}
+	if (io_data->ipv6)
+		nm_vpn_service_plugin_set_ip6_config ((NMVpnServicePlugin*) plugin,
+		                                      g_variant_builder_end (&ip6config));
 
 	/* Send IPv4 config */
-	dbus_g_proxy_call_no_reply (
-		proxy, "SetIp4Config",
-		dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, G_TYPE_VALUE),
-		ip4config,
-		G_TYPE_INVALID,
-		G_TYPE_INVALID);
-
-
-	g_object_unref (proxy);
+	nm_vpn_service_plugin_set_ip4_config ((NMVpnServicePlugin*) plugin,
+	                                      g_variant_builder_end (&ip4config));
 
 	return TRUE;
 }
@@ -691,7 +617,8 @@ nm_ssh_schedule_ifconfig_timer (NMSshPlugin *plugin)
 static gboolean
 nm_ssh_stdout_cb (GIOChannel *source, GIOCondition condition, gpointer user_data)
 {
-	NMVPNPlugin *plugin = NM_VPN_PLUGIN (user_data);
+	NMVpnServicePlugin *plugin = NM_VPN_SERVICE_PLUGIN (user_data);
+	NMSshPluginPrivate *priv = NM_SSH_PLUGIN_GET_PRIVATE (plugin);
 	char *str = NULL;
 
 	if (!(condition & G_IO_IN))
@@ -715,12 +642,12 @@ nm_ssh_stdout_cb (GIOChannel *source, GIOCondition condition, gpointer user_data
 	} else if (g_str_has_prefix (str, "Tunnel device open failed.")) {
 		/* Opening of local tun device failed... :( */
 		g_warning("Tunnel device open failed.");
-		nm_vpn_plugin_set_state (plugin, NM_VPN_SERVICE_STATE_STOPPED);
+		nm_vpn_service_plugin_failure (plugin, NM_VPN_PLUGIN_FAILURE_CONNECT_FAILED);
 	} else if (g_str_has_prefix (str, "debug1: Sending command:")) {
 		/* If we got to sending the command, it means that things are
 		 * established, we should start the timer to get the local
 		 * interface up... */
-		if (NM_VPN_SERVICE_STATE_STOPPED != nm_vpn_plugin_get_state (plugin))
+		if (priv->pid)
 			nm_ssh_schedule_ifconfig_timer ((NMSshPlugin*)plugin);
 		else if(debug)
 			g_message("Not starting local timer because plugin is in STOPPED state");
@@ -728,16 +655,16 @@ nm_ssh_stdout_cb (GIOChannel *source, GIOCondition condition, gpointer user_data
 		/* Opening of remote tun device failed... :( */
 		g_warning("Tunnel device open failed on remote server.");
 		g_warning("Make sure you have privileges to open tun/tap devices and that your SSH server is configured with 'PermitTunnel=yes'");
-		nm_vpn_plugin_set_state (plugin, NM_VPN_SERVICE_STATE_STOPPED);
+		nm_vpn_service_plugin_failure (plugin, NM_VPN_PLUGIN_FAILURE_CONNECT_FAILED);
 	} else if (g_str_has_prefix (str, "debug1: Remote: Failed to open the tunnel device.")) {
 		/* Opening of remote tun device failed... device busy? */
 		g_warning("Tunnel device open failed on remote server.");
 		g_warning("Is this device free on the remote host?");
-		nm_vpn_plugin_set_state (plugin, NM_VPN_SERVICE_STATE_STOPPED);
+		nm_vpn_service_plugin_failure (plugin, NM_VPN_PLUGIN_FAILURE_CONNECT_FAILED);
 	} else if (strncmp (str, "The authenticity of host", 24) == 0) {
 		/* User will have to accept this new host with its fingerprint */
 		g_warning("It is not a known host, continue connecting?");
-		nm_vpn_plugin_set_state (plugin, NM_VPN_SERVICE_STATE_STOPPED);
+		nm_vpn_service_plugin_failure (plugin, NM_VPN_PLUGIN_FAILURE_CONNECT_FAILED);
 	}
 
 	g_message("%s", str);
@@ -768,9 +695,9 @@ nm_ssh_get_free_device (const char *device_type)
 static void
 ssh_watch_cb (GPid pid, gint status, gpointer user_data)
 {
-	NMVPNPlugin *plugin = NM_VPN_PLUGIN (user_data);
+	NMVpnServicePlugin *plugin = NM_VPN_SERVICE_PLUGIN (user_data);
 	NMSshPluginPrivate *priv = NM_SSH_PLUGIN_GET_PRIVATE (plugin);
-	NMVPNPluginFailure failure = NM_VPN_PLUGIN_FAILURE_CONNECT_FAILED;
+	NMVpnPluginFailure failure = NM_VPN_PLUGIN_FAILURE_CONNECT_FAILED;
 	guint error = 0;
 	gboolean good_exit = FALSE;
 
@@ -835,10 +762,10 @@ ssh_watch_cb (GPid pid, gint status, gpointer user_data)
 	g_source_remove(priv->io_data->socket_channel_stderr_eventid);
 	close (g_io_channel_unix_get_fd(priv->io_data->ssh_stderr_channel));
 
-	if (!good_exit)
-		nm_vpn_plugin_failure (plugin, failure);
-
-	nm_vpn_plugin_set_state (plugin, NM_VPN_SERVICE_STATE_STOPPED);
+	if (good_exit)
+		nm_vpn_service_plugin_disconnect (plugin, NULL);
+	else
+		nm_vpn_service_plugin_failure (plugin, failure);
 }
 
 static const char *
@@ -968,7 +895,7 @@ get_known_hosts_file(const char *username,
 
 static gboolean
 nm_ssh_start_ssh_binary (NMSshPlugin *plugin,
-	NMSettingVPN *s_vpn,
+	NMSettingVpn *s_vpn,
 	const char *default_username,
 	GError **error)
 {
@@ -1180,7 +1107,7 @@ nm_ssh_start_ssh_binary (NMSshPlugin *plugin,
 	if (priv->io_data->local_dev_number == -1)
 	{
 		g_warning("Could not assign a free tun/tap device.");
-		nm_vpn_plugin_set_state ((NMVPNPlugin*)plugin, NM_VPN_SERVICE_STATE_STOPPED);
+		nm_vpn_service_plugin_failure (NM_VPN_SERVICE_PLUGIN (plugin), NM_VPN_PLUGIN_FAILURE_CONNECT_FAILED);
 		return FALSE;
 	}
 
@@ -1506,18 +1433,18 @@ validate_ssh_agent_socket(const char* ssh_agent_socket, GError **error)
 }
 
 static gboolean
-real_connect (NMVPNPlugin   *plugin,
+real_connect (NMVpnServicePlugin   *plugin,
 	NMConnection  *connection,
 	GError       **error)
 {
-	NMSettingVPN *s_vpn;
+	NMSettingVpn *s_vpn;
 	const char *user_name;
 
 	s_vpn = NM_SETTING_VPN (nm_connection_get_setting (connection, NM_TYPE_SETTING_VPN));
 	if (!s_vpn) {
 		g_set_error (error,
 		             NM_VPN_PLUGIN_ERROR,
-		             NM_VPN_PLUGIN_ERROR_CONNECTION_INVALID,
+		             NM_VPN_PLUGIN_ERROR_INVALID_CONNECTION,
 		             "%s",
 		             _("Could not process the request because the VPN connection settings were invalid."));
 		return FALSE;
@@ -1537,17 +1464,17 @@ real_connect (NMVPNPlugin   *plugin,
 }
 
 static gboolean
-real_need_secrets (NMVPNPlugin *plugin,
+real_need_secrets (NMVpnServicePlugin *plugin,
 	NMConnection *connection,
-	char **setting_name,
+	const char **setting_name,
 	GError **error)
 {
-	NMSettingVPN *s_vpn;
+	NMSettingVpn *s_vpn;
 	gboolean need_secrets = FALSE;
 	const char *auth_type = NULL;
 	NMSettingSecretFlags flags = NM_SETTING_SECRET_FLAG_NONE;
 
-	g_return_val_if_fail (NM_IS_VPN_PLUGIN (plugin), FALSE);
+	g_return_val_if_fail (NM_IS_VPN_SERVICE_PLUGIN (plugin), FALSE);
 	g_return_val_if_fail (NM_IS_CONNECTION (connection), FALSE);
 
 	if (debug) {
@@ -1559,7 +1486,7 @@ real_need_secrets (NMVPNPlugin *plugin,
 	if (!s_vpn) {
 		g_set_error (error,
 		             NM_VPN_PLUGIN_ERROR,
-		             NM_VPN_PLUGIN_ERROR_CONNECTION_INVALID,
+		             NM_VPN_PLUGIN_ERROR_INVALID_CONNECTION,
 		             "%s",
 		             _("Could not process the request because the VPN connection settings were invalid."));
 		return FALSE;
@@ -1620,7 +1547,7 @@ ensure_killed (gpointer data)
 }
 
 static gboolean
-real_disconnect (NMVPNPlugin	 *plugin,
+real_disconnect (NMVpnServicePlugin	 *plugin,
 			  GError		**err)
 {
 	NMSshPluginPrivate *priv = NM_SSH_PLUGIN_GET_PRIVATE (plugin);
@@ -1647,7 +1574,7 @@ static void
 nm_ssh_plugin_class_init (NMSshPluginClass *plugin_class)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (plugin_class);
-	NMVPNPluginClass *parent_class = NM_VPN_PLUGIN_CLASS (plugin_class);
+	NMVpnServicePluginClass *parent_class = NM_VPN_SERVICE_PLUGIN_CLASS (plugin_class);
 
 	g_type_class_add_private (object_class, sizeof (NMSshPluginPrivate));
 
@@ -1659,7 +1586,7 @@ nm_ssh_plugin_class_init (NMSshPluginClass *plugin_class)
 
 static void
 plugin_state_changed (NMSshPlugin *plugin,
-	NMVPNServiceState state,
+	NMVpnServiceState state,
 	gpointer user_data)
 {
 	switch (state) {
@@ -1679,7 +1606,7 @@ nm_ssh_plugin_new (void)
 	NMSshPlugin *plugin;
 
 	plugin =  (NMSshPlugin *) g_object_new (NM_TYPE_SSH_PLUGIN,
-	                                            NM_VPN_PLUGIN_DBUS_SERVICE_NAME,
+	                                            NM_VPN_SERVICE_PLUGIN_DBUS_SERVICE_NAME,
 	                                            NM_DBUS_SERVICE_SSH,
 	                                            NULL);
 	if (plugin)
@@ -1710,7 +1637,7 @@ setup_signals (void)
 }
 
 static void
-quit_mainloop (NMVPNPlugin *plugin, gpointer user_data)
+quit_mainloop (NMVpnServicePlugin *plugin, gpointer user_data)
 {
 	g_main_loop_quit ((GMainLoop *) user_data);
 }
